const TAG_I18N_TRANSLATIONS = '__i18njs-data';
export var i18nEvents;
(function (i18nEvents) {
  i18nEvents["updateTranslations"] = "i18n-update-translations";
})(i18nEvents || (i18nEvents = {}));
export function raiseEvent(eventName) {
  document.dispatchEvent(new Event(eventName));
}
/**
 * Devuelve la tag que se usará para el localstorage, compuesta por estos
 * elementos, separados por `_`:
 * - TAG estándar `TAG_I18N_TRANSLATIONS`
 * - El idioma de las traducciones
 * - La versión, si no es `undefined` siempre se pone en el último tramo.
 * @param lang idioma de las traducciones
 * @param version versión de las traducciones
 */
function getTag(lang, version) {
  return `${TAG_I18N_TRANSLATIONS}_${lang}_${version || ''}`;
}
export function getStorageT(lang, version) {
  if (version >= 0) {
    const translations = JSON.parse(localStorage.getItem(getTag(lang, version)));
    if (Object.keys(translations).length > 0) {
      return translations;
    }
  }
  return {};
}
export function setStorageT(lang, version, translations) {
  localStorage.setItem(getTag(lang, version), JSON.stringify(translations));
}
export function removeStorageT(lang) {
  Object.keys(localStorage)
    .filter(key => key.includes(getTag(lang)))
    .map(key => localStorage.removeItem(key));
}
export function clearLocalStorage() {
  Object.keys(localStorage)
    .filter(key => key.startsWith(TAG_I18N_TRANSLATIONS))
    .map(key => localStorage.removeItem(key));
}
/**
 * Devuelve la versión, solamente habrá una versión en localstorage, ya que
 * la anterior se elimina antes de guardar la nueva.
 * @param lang El idioma para el que se quieren las traducciones
 */
export function getStorageVersion(lang, defaultVersion = '-1') {
  const tag = Object.keys(localStorage).find((tag) => tag.includes(getTag(lang)));
  const version = tag ? tag.split('_').pop() : defaultVersion;
  return parseFloat(version);
}
