import { II18nOptions, TypeTData } from './utils';
/**
 * Esta clase gestiona todo el contenido de las traducciones
 */
export declare class Translator {
  static instance: Translator;
  private tDonwloader;
  private language;
  private isShowMissing;
  private isLocalValuesAllowed;
  private availableLangs;
  private constructor();
  static getInstance(): Translator;
  static init(options: II18nOptions): Translator;
  static setLocalValuesAllowed(isLocalValuesAllowed?: boolean): void;
  setLocalValuesAllowed(isLocalValuesAllowed?: boolean): void;
  /**
  * Tries to translate a text, returns the text itself if no translation is found.
  * @param originalText text to translate
  * @param tData Interpolation parameters
  * @param lang  Translation language
  * @returns Translated text
  */
  static t(originalText: string, tData?: TypeTData, lang?: string): Promise<string>;
  /**
   * Tries to translate a text, returns the text itself if no translation is found.
   * @param originalText text to translate
   * @param tData Interpolation parameters
   * @param lang  Translation language
   * @returns Translated text
   */
  t(originalText: string, tData?: TypeTData, lang?: string): Promise<string>;
  /**
  * *Función para uso interno*. Recorre las keys del JSON para comprobar si coinciden con el RegExp (p.ej) : `(%key%)`,
  * si coinciden sustituye la palabra por el valor encontrado en el JSON (p.ej) : `(%nombre%)` por `Toni`
  * @param text Texto a interpolar
  * @param data Json que contiene los paramatros del componente (p.ej) : `{ nombre: 'Toni', edad: 25 }`
  * @returns El texto interpolado
  */
  private interpolate;
  /**
   * Changes the language of the application.
   * @param lang new language
   */
  static changeLanguage(lang: string): void;
  /**
   * Changes the language of the application.
   * @param lang new language
   */
  changeLanguage(lang: string): void;
  /**
   * Clears the translations cache and tries to download again the translations.
   */
  static cacheClear(): void;
  /**
   * Clears the translations cache and tries to download again the translations.
   */
  cacheClear(): void;
}
