export interface II18nOptions {
  /** Allowed languages array, if found language is not in this array, will fall back to default, defaults to ['en'] */
  availableLangs: string[];
  /** The default language to select when the selected one is not found in availableLangs, defaults to 'en' */
  defaultLanguage?: string;
  /** Will take precedence over navigator language, defaults to 'en' */
  userLanguage?: string;
  /** Show missing translations in console.warn, defaults to false */
  isShowMissing?: boolean;
  /** Allow the use of cookie `lang` to save the language and localstorage to save translations and versions, defaults to false */
  isLocalValuesAllowed?: boolean;
  /** Api url to get remote updates, defailts to null */
  apiUrl?: string;
  /** App id to get remote updates, defailts to null */
  appId?: string;
  /** App secret to get remote updates, defailts to null */
  appSecret?: string;
  /** The tag that will be sent to server when missing string is found, defaults to 'app' */
  missingTag?: string;
  /** The tags to filter strings on server side, defaults [] */
  tags?: string[];
}
export declare type TypeTData = {
  [key: string]: string;
};
export declare type TypeTranslationsConfig = {
  availableLangs: string[];
  translations: TypeTData;
};
export declare enum i18nEvents {
  updateTranslations = "i18n-update-translations"
}
export declare function raiseEvent(eventName: i18nEvents): void;
export declare function getStorageT(lang: string, version: number): TypeTData | {};
export declare function setStorageT(lang: string, version: number, translations: TypeTData): void;
export declare function removeStorageT(lang: string): void;
export declare function clearLocalStorage(): void;
/**
 * Devuelve la versión, solamente habrá una versión en localstorage, ya que
 * la anterior se elimina antes de guardar la nueva.
 * @param lang El idioma para el que se quieren las traducciones
 */
export declare function getStorageVersion(lang: string, defaultVersion?: string): number;
